@@ -27,7 +27,15 @@ def cal_gain_table(refFile=None, testFile=None,targetType=0):
 
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/gaintable.dll')
+
+    import platform
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/gaintable.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/gaintable.dylib')
+
     mydll.gaintable_estimation.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double,c_double,c_double,POINTER(c_double),POINTER(c_double),POINTER(c_double),POINTER(c_double)]
     data_format = c_double*11
     gain_table = data_format()
